@@ -20,6 +20,25 @@ nonexistent = os.path.join(testdir, "must-not-exist")
 testfile = os.path.abspath(__file__)
 
 
+class TestKeysym(TestCase):
+    def test_keysym_get_name(self):
+        self.assertEqual(xkb.keysym_get_name(0xff68), "Find")
+
+    def test_keysym_from_name(self):
+        self.assertEqual(xkb.keysym_from_name("space"), 0x20)
+
+    def test_keysym_to_string(self):
+        self.assertEqual(xkb.keysym_to_string(0x20), ' ')
+
+    def test_keysym_to_upper(self):
+        # Lower case to upper case A
+        self.assertEqual(xkb.keysym_to_upper(0x61), 0x41)
+
+    def test_keysym_to_lower(self):
+        # Upper case to lower case A
+        self.assertEqual(xkb.keysym_to_lower(0x41), 0x61)
+
+
 class TestContext(TestCase):
     @classmethod
     def setUpClass(cls):
@@ -155,6 +174,25 @@ class TestKeymap(TestCase):
     def test_keymap_iterate_over_keycodes(self):
         self.assertEqual(len(list(self.km)), 245)
 
+    def test_keymap_key_names_roundtrip(self):
+        # Test both key_get_name() and key_by_name()
+        for keycode in iter(self.km):
+            try:
+                name = self.km.key_get_name(keycode)
+                self.assertEqual(self.km.key_by_name(name), keycode)
+            except xkb.XKBInvalidKeycode:
+                pass
+
+    def test_keymap_key_get_name_invalid(self):
+        # Keycode 93 does not exist in our sample keymap
+        with self.assertRaises(xkb.XKBInvalidKeycode):
+            self.km.key_get_name(93)
+
+    def test_keymap_key_by_name_invalid(self):
+        # Keycode 'WIBL' does not exist in our sample keymap
+        with self.assertRaises(xkb.XKBKeyDoesNotExist):
+            self.km.key_by_name("WIBL")
+
     def test_keymap_num_mods(self):
         self.assertEqual(self.km.num_mods(), 21)
 
